%global    gem_name %{name}

# buildrequires libwsman-devel, we mark it by cond build for circular dependency
%ifarch loongarch64
%bcond_with ruby
%else
%bcond_without ruby
%endif

Summary:   Open source Implementation of WS-Management
Name:      openwsman
Version:   2.7.2
Release:   5%{?dist}
License:   BSD
URL:       https://github.com/Openwsman/openwsman
Source0:   %{url}/archive/v%{version}.tar.gz
Source1:   openwsmand.8.gz
Source2:   openwsmand.service
Source3:   owsmantestcert.sh
Source4:   openwsman.te
Source5:   openwsman.if
Source6:   openwsman.fc

Patch3000: openwsman-2.4.0-pamsetup.patch
Patch3001: openwsman-2.4.12-ruby-binding-build.patch
Patch3002: openwsman-2.6.2-openssl-1.1-fix.patch
Patch3003: openwsman-2.6.5-http-status-line.patch
Patch3004: openwsman-2.6.8-update-ssleay-conf.patch

BuildRequires: make swig libcurl-devel libxml2-devel pam-devel sblim-sfcc-devel
BuildRequires: perl-devel perl-generators python3 python3-devel perl-interpreter
BuildRequires: pkgconfig openssl-devel cmake systemd-units gcc gcc-c++

%if %{with ruby}
BuildRequires:  ruby ruby-devel rubygems-devel libwsman-devel
%endif

%description
Openwsman is a project intended to provide an open-source implementation of the Web Services
Management specification (WS-Management) and to expose system management information on the Linux
operating system using the WS-Management protocol. WS-Management is based on a suite of web services
specifications and usage requirements that exposes a set of operations focused on and covers all
system management aspects.

%package -n libwsman1
License:    BSD
Summary:    Open source Implementation of WS-Management
Provides:   %{name} = %{version}-%{release}

%description -n libwsman1
Openwsman library for packages dependent on openwsman.

%package -n libwsman-devel
License:    BSD
Summary:    Open source Implementation of WS-Management
Provides:    %{name}-devel = %{version}-%{release}
Requires:    libwsman1 = %{version}-%{release}
Requires:    %{name}-server = %{version}-%{release}
Requires:    %{name}-client = %{version}-%{release}
Requires:    sblim-sfcc-devel libxml2-devel pam-devel libcurl-devel

%description -n libwsman-devel
Development files for openwsman.

%package client
License:    BSD
Summary:    Openwsman Client libraries

%description client
Openwsman Client libraries.

%package server
License:   BSD
Summary:   Openwsman Server and service libraries
Requires:  libwsman1 = %{version}-%{release}
Requires:  (%{name}-selinux if selinux-policy-targeted)

%description server
Openwsman Server and service libraries.

%package python3
License:    BSD
Summary:    Python bindings for openwsman client API
Requires:    %{__python3}
Requires:    libwsman1 = %{version}-%{release}

%description python3
This package provides Python3 bindings to access the openwsman client API.

%if %{with ruby}
%package -n rubygem-%{name}
License:    BSD
Summary:    Ruby client bindings for Openwsman
Requires:    libwsman1 = %{version}-%{release}

%description -n rubygem-%{name}
The openwsman gem provides a Ruby API to manage systems using the WS-Management protocol.

%package -n rubygem-%{name}-doc
Summary:    Documentation for %{name}
Requires:   rubygem-%{name} = %{version}-%{release}
BuildArch:  noarch

%description -n rubygem-%{name}-doc
Documentation for rubygem-%{name}
%endif

%package perl
License:    BSD
Requires:   perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Summary:    Perl bindings for openwsman client API
Requires:   libwsman1 = %{version}-%{release}

%description perl
This package provides Perl bindings to access the openwsman client API.

%package winrs
Summary:    Windows Remote Shell
Requires:   rubygem-%{name} = %{version}-%{release}

%description winrs
This is a command line tool for the Windows Remote Shell protocol.  You can use it to send shell
commands to a remote Windows hosts.

%package selinux
Summary:   openwsman SELinux policy
BuildRequires: selinux-policy-devel
Requires:  selinux-policy-targeted
Requires(post): selinux-policy-targeted
BuildArch: noarch
%{?selinux_requires}

%description selinux
Custom SELinux policy module

%prep
%autosetup -n %{name}-%{version} -p1

%build
chmod -x src/cpp/WsmanClient.h

rm -rf build
mkdir build

export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -DNO_SSL_CALLBACK"
export CFLAGS="$RPM_OPT_FLAGS -fPIC -pie -Wl,-z,relro -Wl,-z,now"
export CXXFLAGS="$RPM_OPT_FLAGS -fPIC -pie -Wl,-z,relro -Wl,-z,now"
cd build
cmake \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_VERBOSE_MAKEFILE=TRUE \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_C_FLAGS_RELEASE:STRING="$RPM_OPT_FLAGS -fno-strict-aliasing" \
    -DCMAKE_CXX_FLAGS_RELEASE:STRING="$RPM_OPT_FLAGS" \
    -DCMAKE_SKIP_RPATH=1 \
    -DPACKAGE_ARCHITECTURE=`uname -m` \
    -DLIB=%{_lib} \
    -DBUILD_JAVA=no \
    -DBUILD_PYTHON=no \
%if %{without ruby}
    -DBUILD_RUBY=no \
%endif
    ..

%make_build

%if %{with ruby}
export LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build/src/lib
export CPATH=%{_builddir}/%{name}-%{version}/include/
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build/src/lib/

%gem_install -n ./bindings/ruby/%{name}-%{version}.gem
%endif

mkdir selinux
cp -p %{SOURCE4} %{SOURCE5} %{SOURCE6} selinux/
make -f %{_datadir}/selinux/devel/Makefile openwsman.pp
bzip2 -9 openwsman.pp

%install
cd build

%if %{with ruby}
echo -n > bindings/ruby/cmake_install.cmake
%endif

%make_install
cd ..
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/openwsman/plugins/*.la
rm -f %{buildroot}%{_libdir}/openwsman/authenticators/*.la
%if %{with ruby}
[ -d %{buildroot}%{ruby_vendorlibdir} ] && rm -f %{buildroot}%{ruby_vendorlibdir}/openwsmanplugin.rb
[ -d %{buildroot}%{ruby_vendorlibdir} ] && rm -f %{buildroot}%{ruby_vendorlibdir}/openwsman.rb
%endif
mkdir -p %{buildroot}%{_sysconfdir}/init.d
install -m 644 etc/openwsman.conf %{buildroot}%{_sysconfdir}/openwsman
install -m 644 etc/openwsman_client.conf %{buildroot}%{_sysconfdir}/openwsman

install -p -Dm 644 %{SOURCE2} %{buildroot}%{_unitdir}/openwsmand.service
install -m 644 etc/ssleay.cnf %{buildroot}%{_sysconfdir}/openwsman
install -p -m 755 %{SOURCE3} %{buildroot}%{_sysconfdir}/openwsman

install -Dp %{SOURCE1} %{buildroot}%{_mandir}/man8/openwsmand.8.gz

install -m 644 include/wsman-xml.h %{buildroot}%{_includedir}/openwsman
install -m 644 include/wsman-xml-binding.h %{buildroot}%{_includedir}/openwsman
install -m 644 include/wsman-dispatcher.h %{buildroot}%{_includedir}/openwsman

%if %{with ruby}
mkdir -p %{buildroot}%{gem_dir}
cp -pa ./build%{gem_dir}/* \
    %{buildroot}%{gem_dir}/

rm -rf %{buildroot}%{gem_instdir}/ext

mkdir -p %{buildroot}%{gem_extdir_mri}
cp -a ./build%{gem_extdir_mri}/{gem.build_complete,*.so} %{buildroot}%{gem_extdir_mri}/
%endif

install -D -m 0644 build/openwsman.pp.bz2 %{buildroot}%{_datadir}/selinux/packages/targeted/openwsman.pp.bz2
install -D -p -m 0644 build/selinux/openwsman.if %{buildroot}%{_datadir}/selinux/devel/include/distributed/%{name}.if

%post server
%systemd_post openwsmand.service

%preun server
%systemd_preun openwsmand.service

%postun server
rm -f /var/log/wsmand.log
%systemd_postun_with_restart openwsmand.service

%pre selinux
%selinux_relabel_pre -s targeted

%post selinux
%selinux_modules_install -s targeted %{_datadir}/selinux/packages/targeted/openwsman.pp.bz2
%selinux_relabel_post -s targeted

if [ "$1" -le "1" ]; then
   %systemd_postun_with_restart openwsmand.service
fi

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s targeted openwsman
    %selinux_relabel_post -s targeted
fi

%files -n libwsman1
%license COPYING
%doc AUTHORS ChangeLog README.md TODO
%{_libdir}/libwsman.so.*
%{_libdir}/libwsman_client.so.*
%{_libdir}/libwsman_curl_client_transport.so.*

%files -n libwsman-devel
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/*.so

%files python3
%license COPYING
%doc AUTHORS ChangeLog README.md
%{python3_sitearch}/*.so
%{python3_sitearch}/*.py
%{python3_sitearch}/__pycache__/*

%if %{with ruby}
%files -n rubygem-%{name}
%license COPYING
%doc AUTHORS ChangeLog README.md
%dir %{gem_instdir}
%{gem_libdir}
%{gem_extdir_mri}
%exclude %{gem_cache}
%{gem_spec}
%endif

%if %{with ruby}
%files -n rubygem-%{name}-doc
%doc %{gem_docdir}
%endif

%files perl
%license COPYING
%doc AUTHORS ChangeLog README.md
%{perl_vendorarch}/openwsman.so
%{perl_vendorlib}/openwsman.pm

%files server
%license COPYING
%doc AUTHORS ChangeLog README.md
%dir %{_sysconfdir}/openwsman
%config(noreplace) %{_sysconfdir}/openwsman/openwsman.conf
%config(noreplace) %{_sysconfdir}/openwsman/ssleay.cnf
%attr(0755,root,root) %{_sysconfdir}/openwsman/owsmangencert.sh
%attr(0755,root,root) %{_sysconfdir}/openwsman/owsmantestcert.sh
%config(noreplace) %{_sysconfdir}/pam.d/openwsman
%{_unitdir}/openwsmand.service
%dir %{_libdir}/openwsman
%dir %{_libdir}/openwsman/authenticators
%{_libdir}/openwsman/authenticators/*.so
%{_libdir}/openwsman/authenticators/*.so.*
%dir %{_libdir}/openwsman/plugins
%{_libdir}/openwsman/plugins/*.so
%{_libdir}/openwsman/plugins/*.so.*
%{_sbindir}/openwsmand
%{_libdir}/libwsman_server.so.*
%{_mandir}/man8/*

%files client
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_libdir}/libwsman_clientpp.so.*
%config(noreplace) %{_sysconfdir}/openwsman/openwsman_client.conf

%files winrs
%{_bindir}/winrs

%files selinux
%{_datadir}/selinux/packages/targeted/openwsman.pp.*
%{_datadir}/selinux/devel/include/distributed/openwsman.if
%ghost %{_sharedstatedir}/selinux/targeted/active/modules/200/openwsman

%changelog
* Tue Jul 9 2024 Pengda Dou <doupengda@loongson.cn> - 2.7.2-5
- [Type] other
- [DESC] disable ruby for loongarch64

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 2.7.2-4
- Rebuild for curl-8.4.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.7.2-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.7.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 Shuo Wang <abushwang@tencent.com> - 2.7.2-1
- update to 2.7.2

* Wed Jun 7 2023 Shuo Wang <abushwang@tencent.com> - 2.7.1-4
- backport patch to fix build error

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.7.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.7.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 2 2023 Shuo Wang <abushwang@tencent.com> - 2.7.1-1
- initial build
